.. These are examples of badges you might want to add to your README:
   please update the URLs accordingly

    .. image:: https://api.cirrus-ci.com/github/<USER>/exifmgr.svg?branch=main
        :alt: Built Status
        :target: https://cirrus-ci.com/github/<USER>/exifmgr
    .. image:: https://readthedocs.org/projects/exifmgr/badge/?version=latest
        :alt: ReadTheDocs
        :target: https://exifmgr.readthedocs.io/en/stable/
    .. image:: https://img.shields.io/coveralls/github/<USER>/exifmgr/main.svg
        :alt: Coveralls
        :target: https://coveralls.io/r/<USER>/exifmgr
    .. image:: https://img.shields.io/pypi/v/exifmgr.svg
        :alt: PyPI-Server
        :target: https://pypi.org/project/exifmgr/
    .. image:: https://img.shields.io/conda/vn/conda-forge/exifmgr.svg
        :alt: Conda-Forge
        :target: https://anaconda.org/conda-forge/exifmgr
    .. image:: https://pepy.tech/badge/exifmgr/month
        :alt: Monthly Downloads
        :target: https://pepy.tech/project/exifmgr
    .. image:: https://img.shields.io/twitter/url/http/shields.io.svg?style=social&label=Twitter
        :alt: Twitter
        :target: https://twitter.com/exifmgr

.. image:: https://img.shields.io/badge/-PyScaffold-005CA0?logo=pyscaffold
    :alt: Project generated with PyScaffold
    :target: https://pyscaffold.org/

|

=======
exifmgr
=======


    Add a short description here!


A longer description of your project goes here...


.. _pyscaffold-notes:

Note
====

This project has been set up using PyScaffold 4.3. For details and usage
information on PyScaffold see https://pyscaffold.org/.
